#! /usr/bin/python
# -*- coding: utf-8 -*-

from gi.repository import Gtk, Gio
import signal
import subprocess
import shlex

class GEDUConfig(Gtk.Window):

    def execute(self, command):
        args = shlex.split(command)
        p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
        out, err = p.communicate()
        return out, err

    def AutologinStatus(self):
        # Commands to execute for MD5 checksums
        withautologin = "md5sum /usr/share/cga/cga-lightdm-config/lightdm-sdi.conf"
        withoutautologin = "md5sum /usr/share/cga/cga-lightdm-config/lightdm.conf"
        status = "md5sum /etc/lightdm/lightdm.conf"

        # Execution of the command
        md5with, _ = self.execute(withautologin)
        md5without, _ = self.execute(withoutautologin)
        md5config, _ = self.execute(status)

        # Strip only MD5 checksums
        md5with = ''.join(md5with).split(' ')[0]
        md5without = ''.join(md5without).split(' ')[0]
        md5config = ''.join(md5config).split(' ')[0]

        if md5config == md5with:
            return True
        elif md5config == md5without:
            return False
        else:
            return False

    def on_autologin_switch_changed(self, switch, gparam):
        # Autologin is active in lightdm.conf:
        if self.AutologinStatus() == True:
            # Deactivating autologin
            self.execute("sudo /usr/share/guadalinexedu-configurator/setautologin deactivate")
        # Autologin isn't active in lightdm.conf:
        else:
            # Activating autologin
            self.execute("sudo /usr/share/guadalinexedu-configurator/setautologin activate")


    def __init__(self):
        """ Class init event """
        # Setup the window with title and border width.
        Gtk.Window.__init__(self, type=Gtk.WindowType.TOPLEVEL,
                                  title="Configurador de Escritorio de Guadalinex EDU",
                                  resizable=False,
                                  border_width=10)

        # Create a Vertical child box.
        vbox = Gtk.Box.new(Gtk.Orientation.VERTICAL, 6)

        # Create and bind the Gtk Switch with the gsettings schema and its key.
        # volumes-visible path in nautilus.desktop schema
        nautilus_desktop_switch = Gtk.Switch()
        nautilus_desktop_setting = Gio.Settings.new("org.gnome.nautilus.desktop")
        nautilus_desktop_setting.bind("volumes-visible", nautilus_desktop_switch, "active", Gio.SettingsBindFlags.DEFAULT)

        # Create the label for the volumes visible switch
        volumes_visible_label = Gtk.Label("Mostrar en el escritorio los volúmenes montados")

        # Create the autologin switch
        autologin_switch = Gtk.Switch()
        autologin_switch.set_active(self.AutologinStatus())
        autologin_switch.connect("notify::active", self.on_autologin_switch_changed)

        # Create the label for the autologin switch
        autologin_label = Gtk.Label("Login automático para el usuario \"usuario\"")

        # Position the Switch and its Label inside a Horizontal child box.
        box = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 40)
        box.pack_start(volumes_visible_label, False, False, 10)
        box.pack_end(nautilus_desktop_switch, False, False, 10)
        vbox.pack_start(box, False, False, 0)

        box = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 40)
        box.pack_start(autologin_label, False, False, 10)
        box.pack_end(autologin_switch, False, False, 10)
        vbox.pack_start(box, False, False, 1)

        # Add the child box to the window
        self.add(vbox)
        self.connect("destroy", Gtk.main_quit)
        signal.signal(signal.SIGINT, signal.SIG_DFL)

if __name__ == "__main__":
    window = GEDUConfig()
    window.set_position(Gtk.WindowPosition.CENTER)
    window.show_all()
    Gtk.main()
